import 'dart:io';

import 'package:flutter/foundation.dart';
import 'package:flutter_admob_app_open/flutter_admob_app_open.dart';
import 'package:google_mobile_ads/google_mobile_ads.dart';


/// [IOS AD IDS]
const IOS_BANNER_AD_ID = '';
const IOS_INTERSTITIAL_AD_ID = '';
const IOS_NATIVE_AD_ID = '';
const IOS_APP_OPEN_AD_ID = '';

/// [ANDROID AD IDS]
const ANDROID_BANNER_AD_ID = '';
const ANDROID_INTERSTITIAL_AD_ID = '';
const ANDROID_NATIVE_AD_ID = '';
const ANDROID_APP_OPEN_AD_ID = '';

/// [TEST AD IDS]
const BANNER_TEST_AD_ID = 'ca-app-pub-3940256099942544/6300978111';
const INTERSTITIAL_TEST_AD_ID = 'ca-app-pub-3940256099942544/1033173712';
const NATIVE_TEST_AD_ID = 'ca-app-pub-3940256099942544/2247696110';
final appAppOpenAdUnitId = FlutterAdmobAppOpen.testAppOpenAdId;

class AdsUtil {
  static BannerAd get banner => new BannerAd(
    adUnitId: kDebugMode
        ? BANNER_TEST_AD_ID
        : Platform.isIOS
        ? IOS_BANNER_AD_ID
        : ANDROID_BANNER_AD_ID,
    size: AdSize.banner,
    request: AdRequest(),
    listener: BannerAdListener(),
  );

  static InterstitialAd? interstitialAd;
  static bool _isLoaded = false;

  static Future<void> initAds() async {
    const String testDeviceMySimulator = 'AB8C0062-1308-4624-BE5A-AD2486C635D4';
    const String myAndroid = '9B03565017C05051FFD28151A7ECF4B5';

    await MobileAds.instance.initialize().then((value) async {
      await MobileAds.instance.updateRequestConfiguration(
        RequestConfiguration(testDeviceIds: [testDeviceMySimulator, myAndroid]),
      );
    });

    AdRequestAppOpen targetingInfo = AdRequestAppOpen(
      // keywords: <String>['flutterio', 'beautiful apps'],
      // contentUrl: 'https://flutter.io',
      nonPersonalizedAds: false,
    );
    await FlutterAdmobAppOpen.instance.initialize(
      appAppOpenAdUnitId: kDebugMode
          ? appAppOpenAdUnitId
          : Platform.isIOS
          ? IOS_APP_OPEN_AD_ID
          : ANDROID_APP_OPEN_AD_ID,
      targetingInfo: targetingInfo,
    );
    FlutterAdmobAppOpen.instance.pause();
  }

  static void showInterstitialAd() {
    if (interstitialAd != null && _isLoaded) {
      interstitialAd!.show().then((value) => preloadAd());
    }
  }

  static void preloadAd() async {
    _isLoaded = false;
    //if (Get.find<PurchaseHandle>().isPremium.value) return;
    await InterstitialAd.load(
      adUnitId: kDebugMode
          ? INTERSTITIAL_TEST_AD_ID
          : Platform.isIOS
          ? IOS_INTERSTITIAL_AD_ID
          : ANDROID_INTERSTITIAL_AD_ID,
      request: AdRequest(),
      adLoadCallback: InterstitialAdLoadCallback(
        onAdLoaded: (InterstitialAd ad) {
          interstitialAd = ad;
          _isLoaded = true;
        },
        onAdFailedToLoad: (LoadAdError error) {
          print('InterstitialAd failed to load: $error');
          _isLoaded = false;
        },
      ),
    );
  }

  static NativeAd nativeAd(VoidCallback onAdLoaded) => NativeAd(
    adUnitId: kDebugMode
        ? NATIVE_TEST_AD_ID
        : Platform.isIOS
        ? IOS_NATIVE_AD_ID
        : ANDROID_NATIVE_AD_ID,
    factoryId: 'NativeAdView',
    listener: NativeAdListener(onAdFailedToLoad: (ad, _) {
      ad.dispose();
    }, onAdLoaded: (ad) {
      onAdLoaded();
    }),
    request: AdRequest(),
  );
}

class AdModel {
  ValueNotifier<bool> isLoaded = ValueNotifier(false);
  late NativeAd ad;
  AdModel() {
    ad = AdsUtil.nativeAd(() {
      this.isLoaded.value = true;
    });
  }
}